@@ -12,3 +12,7 @@
 #
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>
+
+version = '0.7'
+import logging
+logging.basicConfig(format="%(asctime)-15s %(levelname)s %(message)s")
